#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OperationTaskDTO import OperationTaskDTO


class PageInfoDTO(object):

    def __init__(self):
        self._code = None
        self._creator_id = None
        self._creator_name = None
        self._current_version = None
        self._edit_version = None
        self._gmt_create = None
        self._gmt_create_code = None
        self._gmt_modified = None
        self._id = None
        self._modifier_id = None
        self._modifier_name = None
        self._name = None
        self._operation_task = None
        self._operation_task_id = None
        self._page_template_type = None
        self._peiqi_status = None
        self._promo_benefit_code = None
        self._reject_reason = None
        self._render_url = None
        self._run_version = None
        self._status = None
        self._template_code = None
        self._template_params = None
        self._tenant_code = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def creator_name(self):
        return self._creator_name

    @creator_name.setter
    def creator_name(self, value):
        self._creator_name = value
    @property
    def current_version(self):
        return self._current_version

    @current_version.setter
    def current_version(self, value):
        self._current_version = value
    @property
    def edit_version(self):
        return self._edit_version

    @edit_version.setter
    def edit_version(self, value):
        self._edit_version = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_create_code(self):
        return self._gmt_create_code

    @gmt_create_code.setter
    def gmt_create_code(self, value):
        self._gmt_create_code = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def modifier_id(self):
        return self._modifier_id

    @modifier_id.setter
    def modifier_id(self, value):
        self._modifier_id = value
    @property
    def modifier_name(self):
        return self._modifier_name

    @modifier_name.setter
    def modifier_name(self, value):
        self._modifier_name = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def operation_task(self):
        return self._operation_task

    @operation_task.setter
    def operation_task(self, value):
        if isinstance(value, OperationTaskDTO):
            self._operation_task = value
        else:
            self._operation_task = OperationTaskDTO.from_alipay_dict(value)
    @property
    def operation_task_id(self):
        return self._operation_task_id

    @operation_task_id.setter
    def operation_task_id(self, value):
        self._operation_task_id = value
    @property
    def page_template_type(self):
        return self._page_template_type

    @page_template_type.setter
    def page_template_type(self, value):
        self._page_template_type = value
    @property
    def peiqi_status(self):
        return self._peiqi_status

    @peiqi_status.setter
    def peiqi_status(self, value):
        self._peiqi_status = value
    @property
    def promo_benefit_code(self):
        return self._promo_benefit_code

    @promo_benefit_code.setter
    def promo_benefit_code(self, value):
        self._promo_benefit_code = value
    @property
    def reject_reason(self):
        return self._reject_reason

    @reject_reason.setter
    def reject_reason(self, value):
        self._reject_reason = value
    @property
    def render_url(self):
        return self._render_url

    @render_url.setter
    def render_url(self, value):
        self._render_url = value
    @property
    def run_version(self):
        return self._run_version

    @run_version.setter
    def run_version(self, value):
        self._run_version = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def template_code(self):
        return self._template_code

    @template_code.setter
    def template_code(self, value):
        self._template_code = value
    @property
    def template_params(self):
        return self._template_params

    @template_params.setter
    def template_params(self, value):
        self._template_params = value
    @property
    def tenant_code(self):
        return self._tenant_code

    @tenant_code.setter
    def tenant_code(self, value):
        self._tenant_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.creator_id:
            if hasattr(self.creator_id, 'to_alipay_dict'):
                params['creator_id'] = self.creator_id.to_alipay_dict()
            else:
                params['creator_id'] = self.creator_id
        if self.creator_name:
            if hasattr(self.creator_name, 'to_alipay_dict'):
                params['creator_name'] = self.creator_name.to_alipay_dict()
            else:
                params['creator_name'] = self.creator_name
        if self.current_version:
            if hasattr(self.current_version, 'to_alipay_dict'):
                params['current_version'] = self.current_version.to_alipay_dict()
            else:
                params['current_version'] = self.current_version
        if self.edit_version:
            if hasattr(self.edit_version, 'to_alipay_dict'):
                params['edit_version'] = self.edit_version.to_alipay_dict()
            else:
                params['edit_version'] = self.edit_version
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_create_code:
            if hasattr(self.gmt_create_code, 'to_alipay_dict'):
                params['gmt_create_code'] = self.gmt_create_code.to_alipay_dict()
            else:
                params['gmt_create_code'] = self.gmt_create_code
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.modifier_id:
            if hasattr(self.modifier_id, 'to_alipay_dict'):
                params['modifier_id'] = self.modifier_id.to_alipay_dict()
            else:
                params['modifier_id'] = self.modifier_id
        if self.modifier_name:
            if hasattr(self.modifier_name, 'to_alipay_dict'):
                params['modifier_name'] = self.modifier_name.to_alipay_dict()
            else:
                params['modifier_name'] = self.modifier_name
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.operation_task:
            if hasattr(self.operation_task, 'to_alipay_dict'):
                params['operation_task'] = self.operation_task.to_alipay_dict()
            else:
                params['operation_task'] = self.operation_task
        if self.operation_task_id:
            if hasattr(self.operation_task_id, 'to_alipay_dict'):
                params['operation_task_id'] = self.operation_task_id.to_alipay_dict()
            else:
                params['operation_task_id'] = self.operation_task_id
        if self.page_template_type:
            if hasattr(self.page_template_type, 'to_alipay_dict'):
                params['page_template_type'] = self.page_template_type.to_alipay_dict()
            else:
                params['page_template_type'] = self.page_template_type
        if self.peiqi_status:
            if hasattr(self.peiqi_status, 'to_alipay_dict'):
                params['peiqi_status'] = self.peiqi_status.to_alipay_dict()
            else:
                params['peiqi_status'] = self.peiqi_status
        if self.promo_benefit_code:
            if hasattr(self.promo_benefit_code, 'to_alipay_dict'):
                params['promo_benefit_code'] = self.promo_benefit_code.to_alipay_dict()
            else:
                params['promo_benefit_code'] = self.promo_benefit_code
        if self.reject_reason:
            if hasattr(self.reject_reason, 'to_alipay_dict'):
                params['reject_reason'] = self.reject_reason.to_alipay_dict()
            else:
                params['reject_reason'] = self.reject_reason
        if self.render_url:
            if hasattr(self.render_url, 'to_alipay_dict'):
                params['render_url'] = self.render_url.to_alipay_dict()
            else:
                params['render_url'] = self.render_url
        if self.run_version:
            if hasattr(self.run_version, 'to_alipay_dict'):
                params['run_version'] = self.run_version.to_alipay_dict()
            else:
                params['run_version'] = self.run_version
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.template_code:
            if hasattr(self.template_code, 'to_alipay_dict'):
                params['template_code'] = self.template_code.to_alipay_dict()
            else:
                params['template_code'] = self.template_code
        if self.template_params:
            if hasattr(self.template_params, 'to_alipay_dict'):
                params['template_params'] = self.template_params.to_alipay_dict()
            else:
                params['template_params'] = self.template_params
        if self.tenant_code:
            if hasattr(self.tenant_code, 'to_alipay_dict'):
                params['tenant_code'] = self.tenant_code.to_alipay_dict()
            else:
                params['tenant_code'] = self.tenant_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PageInfoDTO()
        if 'code' in d:
            o.code = d['code']
        if 'creator_id' in d:
            o.creator_id = d['creator_id']
        if 'creator_name' in d:
            o.creator_name = d['creator_name']
        if 'current_version' in d:
            o.current_version = d['current_version']
        if 'edit_version' in d:
            o.edit_version = d['edit_version']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_create_code' in d:
            o.gmt_create_code = d['gmt_create_code']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'id' in d:
            o.id = d['id']
        if 'modifier_id' in d:
            o.modifier_id = d['modifier_id']
        if 'modifier_name' in d:
            o.modifier_name = d['modifier_name']
        if 'name' in d:
            o.name = d['name']
        if 'operation_task' in d:
            o.operation_task = d['operation_task']
        if 'operation_task_id' in d:
            o.operation_task_id = d['operation_task_id']
        if 'page_template_type' in d:
            o.page_template_type = d['page_template_type']
        if 'peiqi_status' in d:
            o.peiqi_status = d['peiqi_status']
        if 'promo_benefit_code' in d:
            o.promo_benefit_code = d['promo_benefit_code']
        if 'reject_reason' in d:
            o.reject_reason = d['reject_reason']
        if 'render_url' in d:
            o.render_url = d['render_url']
        if 'run_version' in d:
            o.run_version = d['run_version']
        if 'status' in d:
            o.status = d['status']
        if 'template_code' in d:
            o.template_code = d['template_code']
        if 'template_params' in d:
            o.template_params = d['template_params']
        if 'tenant_code' in d:
            o.tenant_code = d['tenant_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InputScheduleTime(object):

    def __init__(self):
        self._capacity = None
        self._direction = None
        self._exp_trip_cnt = None
        self._ext_param = None
        self._line_id = None

    @property
    def capacity(self):
        return self._capacity

    @capacity.setter
    def capacity(self, value):
        self._capacity = value
    @property
    def direction(self):
        return self._direction

    @direction.setter
    def direction(self, value):
        self._direction = value
    @property
    def exp_trip_cnt(self):
        return self._exp_trip_cnt

    @exp_trip_cnt.setter
    def exp_trip_cnt(self, value):
        self._exp_trip_cnt = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def line_id(self):
        return self._line_id

    @line_id.setter
    def line_id(self, value):
        self._line_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.capacity:
            if hasattr(self.capacity, 'to_alipay_dict'):
                params['capacity'] = self.capacity.to_alipay_dict()
            else:
                params['capacity'] = self.capacity
        if self.direction:
            if hasattr(self.direction, 'to_alipay_dict'):
                params['direction'] = self.direction.to_alipay_dict()
            else:
                params['direction'] = self.direction
        if self.exp_trip_cnt:
            if hasattr(self.exp_trip_cnt, 'to_alipay_dict'):
                params['exp_trip_cnt'] = self.exp_trip_cnt.to_alipay_dict()
            else:
                params['exp_trip_cnt'] = self.exp_trip_cnt
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.line_id:
            if hasattr(self.line_id, 'to_alipay_dict'):
                params['line_id'] = self.line_id.to_alipay_dict()
            else:
                params['line_id'] = self.line_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InputScheduleTime()
        if 'capacity' in d:
            o.capacity = d['capacity']
        if 'direction' in d:
            o.direction = d['direction']
        if 'exp_trip_cnt' in d:
            o.exp_trip_cnt = d['exp_trip_cnt']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'line_id' in d:
            o.line_id = d['line_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EcnyAddressInfo(object):

    def __init__(self):
        self._address = None
        self._city_code = None
        self._country = None
        self._district_code = None
        self._latitude = None
        self._longitude = None
        self._province_code = None
        self._type = None
        self._zip = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def country(self):
        return self._country

    @country.setter
    def country(self, value):
        self._country = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def zip(self):
        return self._zip

    @zip.setter
    def zip(self, value):
        self._zip = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.country:
            if hasattr(self.country, 'to_alipay_dict'):
                params['country'] = self.country.to_alipay_dict()
            else:
                params['country'] = self.country
        if self.district_code:
            if hasattr(self.district_code, 'to_alipay_dict'):
                params['district_code'] = self.district_code.to_alipay_dict()
            else:
                params['district_code'] = self.district_code
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.zip:
            if hasattr(self.zip, 'to_alipay_dict'):
                params['zip'] = self.zip.to_alipay_dict()
            else:
                params['zip'] = self.zip
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EcnyAddressInfo()
        if 'address' in d:
            o.address = d['address']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'country' in d:
            o.country = d['country']
        if 'district_code' in d:
            o.district_code = d['district_code']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'type' in d:
            o.type = d['type']
        if 'zip' in d:
            o.zip = d['zip']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ExtContext import ExtContext


class HuanxuTradeOrderCloseResponse(AlipayResponse):

    def __init__(self):
        super(HuanxuTradeOrderCloseResponse, self).__init__()
        self._channel = None
        self._ext_context = None
        self._pay_amount = None
        self._pay_request_no = None
        self._payment_id = None

    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def ext_context(self):
        return self._ext_context

    @ext_context.setter
    def ext_context(self, value):
        if isinstance(value, ExtContext):
            self._ext_context = value
        else:
            self._ext_context = ExtContext.from_alipay_dict(value)
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def pay_request_no(self):
        return self._pay_request_no

    @pay_request_no.setter
    def pay_request_no(self, value):
        self._pay_request_no = value
    @property
    def payment_id(self):
        return self._payment_id

    @payment_id.setter
    def payment_id(self, value):
        self._payment_id = value

    def parse_response_content(self, response_content):
        response = super(HuanxuTradeOrderCloseResponse, self).parse_response_content(response_content)
        if 'channel' in response:
            self.channel = response['channel']
        if 'ext_context' in response:
            self.ext_context = response['ext_context']
        if 'pay_amount' in response:
            self.pay_amount = response['pay_amount']
        if 'pay_request_no' in response:
            self.pay_request_no = response['pay_request_no']
        if 'payment_id' in response:
            self.payment_id = response['payment_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoEduKtZftschoolQueryModel(object):

    def __init__(self):
        self._order_id = None
        self._partner_pid = None

    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def partner_pid(self):
        return self._partner_pid

    @partner_pid.setter
    def partner_pid(self, value):
        self._partner_pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.partner_pid:
            if hasattr(self.partner_pid, 'to_alipay_dict'):
                params['partner_pid'] = self.partner_pid.to_alipay_dict()
            else:
                params['partner_pid'] = self.partner_pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoEduKtZftschoolQueryModel()
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'partner_pid' in d:
            o.partner_pid = d['partner_pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenPublicLifeAccountCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicLifeAccountCreateResponse, self).__init__()
        self._expire_time = None
        self._public_id = None
        self._refresh_token = None
        self._token = None

    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def public_id(self):
        return self._public_id

    @public_id.setter
    def public_id(self, value):
        self._public_id = value
    @property
    def refresh_token(self):
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, value):
        self._refresh_token = value
    @property
    def token(self):
        return self._token

    @token.setter
    def token(self, value):
        self._token = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicLifeAccountCreateResponse, self).parse_response_content(response_content)
        if 'expire_time' in response:
            self.expire_time = response['expire_time']
        if 'public_id' in response:
            self.public_id = response['public_id']
        if 'refresh_token' in response:
            self.refresh_token = response['refresh_token']
        if 'token' in response:
            self.token = response['token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TaskBaseInfo import TaskBaseInfo


class AlipayMarketingCampaignTaskSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignTaskSendResponse, self).__init__()
        self._task_base_info = None
        self._task_id = None
        self._trigger_result = None

    @property
    def task_base_info(self):
        return self._task_base_info

    @task_base_info.setter
    def task_base_info(self, value):
        if isinstance(value, TaskBaseInfo):
            self._task_base_info = value
        else:
            self._task_base_info = TaskBaseInfo.from_alipay_dict(value)
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value
    @property
    def trigger_result(self):
        return self._trigger_result

    @trigger_result.setter
    def trigger_result(self, value):
        self._trigger_result = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignTaskSendResponse, self).parse_response_content(response_content)
        if 'task_base_info' in response:
            self.task_base_info = response['task_base_info']
        if 'task_id' in response:
            self.task_id = response['task_id']
        if 'trigger_result' in response:
            self.trigger_result = response['trigger_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntMerchantExpandIndirectZftConsultResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandIndirectZftConsultResponse, self).__init__()
        self._account_audit = None
        self._order_id = None
        self._risk_audit = None

    @property
    def account_audit(self):
        return self._account_audit

    @account_audit.setter
    def account_audit(self, value):
        self._account_audit = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def risk_audit(self):
        return self._risk_audit

    @risk_audit.setter
    def risk_audit(self, value):
        self._risk_audit = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandIndirectZftConsultResponse, self).parse_response_content(response_content)
        if 'account_audit' in response:
            self.account_audit = response['account_audit']
        if 'order_id' in response:
            self.order_id = response['order_id']
        if 'risk_audit' in response:
            self.risk_audit = response['risk_audit']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AvailableTimeInfo(object):

    def __init__(self):
        self._available_days = None
        self._from_time = None
        self._limit_period_unit = None
        self._to_time = None

    @property
    def available_days(self):
        return self._available_days

    @available_days.setter
    def available_days(self, value):
        if isinstance(value, list):
            self._available_days = list()
            for i in value:
                self._available_days.append(i)
    @property
    def from_time(self):
        return self._from_time

    @from_time.setter
    def from_time(self, value):
        self._from_time = value
    @property
    def limit_period_unit(self):
        return self._limit_period_unit

    @limit_period_unit.setter
    def limit_period_unit(self, value):
        self._limit_period_unit = value
    @property
    def to_time(self):
        return self._to_time

    @to_time.setter
    def to_time(self, value):
        self._to_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.available_days:
            if isinstance(self.available_days, list):
                for i in range(0, len(self.available_days)):
                    element = self.available_days[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.available_days[i] = element.to_alipay_dict()
            if hasattr(self.available_days, 'to_alipay_dict'):
                params['available_days'] = self.available_days.to_alipay_dict()
            else:
                params['available_days'] = self.available_days
        if self.from_time:
            if hasattr(self.from_time, 'to_alipay_dict'):
                params['from_time'] = self.from_time.to_alipay_dict()
            else:
                params['from_time'] = self.from_time
        if self.limit_period_unit:
            if hasattr(self.limit_period_unit, 'to_alipay_dict'):
                params['limit_period_unit'] = self.limit_period_unit.to_alipay_dict()
            else:
                params['limit_period_unit'] = self.limit_period_unit
        if self.to_time:
            if hasattr(self.to_time, 'to_alipay_dict'):
                params['to_time'] = self.to_time.to_alipay_dict()
            else:
                params['to_time'] = self.to_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AvailableTimeInfo()
        if 'available_days' in d:
            o.available_days = d['available_days']
        if 'from_time' in d:
            o.from_time = d['from_time']
        if 'limit_period_unit' in d:
            o.limit_period_unit = d['limit_period_unit']
        if 'to_time' in d:
            o.to_time = d['to_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcapiprodDataPutResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcapiprodDataPutResponse, self).__init__()
        self._data_version = None

    @property
    def data_version(self):
        return self._data_version

    @data_version.setter
    def data_version(self, value):
        self._data_version = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcapiprodDataPutResponse, self).parse_response_content(response_content)
        if 'data_version' in response:
            self.data_version = response['data_version']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEcConsumeDetailBatchqueryModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._end_date = None
        self._enterprise_id = None
        self._page_num = None
        self._page_size = None
        self._start_date = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEcConsumeDetailBatchqueryModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'start_date' in d:
            o.start_date = d['start_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAppTestTestChargeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppTestTestChargeResponse, self).__init__()
        self._name = None

    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppTestTestChargeResponse, self).parse_response_content(response_content)
        if 'name' in response:
            self.name = response['name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VcpAssetDetail(object):

    def __init__(self):
        self._amount = None
        self._assetamount = None
        self._assetusechannel = None
        self._settleuserid = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def assetamount(self):
        return self._assetamount

    @assetamount.setter
    def assetamount(self, value):
        self._assetamount = value
    @property
    def assetusechannel(self):
        return self._assetusechannel

    @assetusechannel.setter
    def assetusechannel(self, value):
        self._assetusechannel = value
    @property
    def settleuserid(self):
        return self._settleuserid

    @settleuserid.setter
    def settleuserid(self, value):
        self._settleuserid = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.assetamount:
            if hasattr(self.assetamount, 'to_alipay_dict'):
                params['assetamount'] = self.assetamount.to_alipay_dict()
            else:
                params['assetamount'] = self.assetamount
        if self.assetusechannel:
            if hasattr(self.assetusechannel, 'to_alipay_dict'):
                params['assetusechannel'] = self.assetusechannel.to_alipay_dict()
            else:
                params['assetusechannel'] = self.assetusechannel
        if self.settleuserid:
            if hasattr(self.settleuserid, 'to_alipay_dict'):
                params['settleuserid'] = self.settleuserid.to_alipay_dict()
            else:
                params['settleuserid'] = self.settleuserid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VcpAssetDetail()
        if 'amount' in d:
            o.amount = d['amount']
        if 'assetamount' in d:
            o.assetamount = d['assetamount']
        if 'assetusechannel' in d:
            o.assetusechannel = d['assetusechannel']
        if 'settleuserid' in d:
            o.settleuserid = d['settleuserid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZolozAuthenticationCustomerFacemanageDeleteResponse(AlipayResponse):

    def __init__(self):
        super(ZolozAuthenticationCustomerFacemanageDeleteResponse, self).__init__()
        self._result = None
        self._retcode = None
        self._retcodesub = None
        self._retmessage = None
        self._retmessagesub = None

    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value
    @property
    def retcode(self):
        return self._retcode

    @retcode.setter
    def retcode(self, value):
        self._retcode = value
    @property
    def retcodesub(self):
        return self._retcodesub

    @retcodesub.setter
    def retcodesub(self, value):
        self._retcodesub = value
    @property
    def retmessage(self):
        return self._retmessage

    @retmessage.setter
    def retmessage(self, value):
        self._retmessage = value
    @property
    def retmessagesub(self):
        return self._retmessagesub

    @retmessagesub.setter
    def retmessagesub(self, value):
        self._retmessagesub = value

    def parse_response_content(self, response_content):
        response = super(ZolozAuthenticationCustomerFacemanageDeleteResponse, self).parse_response_content(response_content)
        if 'result' in response:
            self.result = response['result']
        if 'retcode' in response:
            self.retcode = response['retcode']
        if 'retcodesub' in response:
            self.retcodesub = response['retcodesub']
        if 'retmessage' in response:
            self.retmessage = response['retmessage']
        if 'retmessagesub' in response:
            self.retmessagesub = response['retmessagesub']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenStsTokenGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenStsTokenGetResponse, self).__init__()
        self._expiration = None
        self._security_token = None

    @property
    def expiration(self):
        return self._expiration

    @expiration.setter
    def expiration(self, value):
        self._expiration = value
    @property
    def security_token(self):
        return self._security_token

    @security_token.setter
    def security_token(self, value):
        self._security_token = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenStsTokenGetResponse, self).parse_response_content(response_content)
        if 'expiration' in response:
            self.expiration = response['expiration']
        if 'security_token' in response:
            self.security_token = response['security_token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class NodeOperateDTO(object):

    def __init__(self):
        self._ant_process_puid = None
        self._biz_app = None
        self._biz_id = None
        self._biz_type = None
        self._memo = None
        self._node_display_name = None
        self._node_duration = None
        self._node_name = None
        self._operate_detail = None
        self._operate_duration = None
        self._operate_time = None
        self._operate_type = None
        self._operator = None
        self._operator_name = None
        self._operator_work_no = None
        self._ticket_state = None
        self._title = None

    @property
    def ant_process_puid(self):
        return self._ant_process_puid

    @ant_process_puid.setter
    def ant_process_puid(self, value):
        self._ant_process_puid = value
    @property
    def biz_app(self):
        return self._biz_app

    @biz_app.setter
    def biz_app(self, value):
        self._biz_app = value
    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def node_display_name(self):
        return self._node_display_name

    @node_display_name.setter
    def node_display_name(self, value):
        self._node_display_name = value
    @property
    def node_duration(self):
        return self._node_duration

    @node_duration.setter
    def node_duration(self, value):
        self._node_duration = value
    @property
    def node_name(self):
        return self._node_name

    @node_name.setter
    def node_name(self, value):
        self._node_name = value
    @property
    def operate_detail(self):
        return self._operate_detail

    @operate_detail.setter
    def operate_detail(self, value):
        self._operate_detail = value
    @property
    def operate_duration(self):
        return self._operate_duration

    @operate_duration.setter
    def operate_duration(self, value):
        self._operate_duration = value
    @property
    def operate_time(self):
        return self._operate_time

    @operate_time.setter
    def operate_time(self, value):
        self._operate_time = value
    @property
    def operate_type(self):
        return self._operate_type

    @operate_type.setter
    def operate_type(self, value):
        self._operate_type = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def operator_name(self):
        return self._operator_name

    @operator_name.setter
    def operator_name(self, value):
        self._operator_name = value
    @property
    def operator_work_no(self):
        return self._operator_work_no

    @operator_work_no.setter
    def operator_work_no(self, value):
        self._operator_work_no = value
    @property
    def ticket_state(self):
        return self._ticket_state

    @ticket_state.setter
    def ticket_state(self, value):
        self._ticket_state = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.ant_process_puid:
            if hasattr(self.ant_process_puid, 'to_alipay_dict'):
                params['ant_process_puid'] = self.ant_process_puid.to_alipay_dict()
            else:
                params['ant_process_puid'] = self.ant_process_puid
        if self.biz_app:
            if hasattr(self.biz_app, 'to_alipay_dict'):
                params['biz_app'] = self.biz_app.to_alipay_dict()
            else:
                params['biz_app'] = self.biz_app
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.node_display_name:
            if hasattr(self.node_display_name, 'to_alipay_dict'):
                params['node_display_name'] = self.node_display_name.to_alipay_dict()
            else:
                params['node_display_name'] = self.node_display_name
        if self.node_duration:
            if hasattr(self.node_duration, 'to_alipay_dict'):
                params['node_duration'] = self.node_duration.to_alipay_dict()
            else:
                params['node_duration'] = self.node_duration
        if self.node_name:
            if hasattr(self.node_name, 'to_alipay_dict'):
                params['node_name'] = self.node_name.to_alipay_dict()
            else:
                params['node_name'] = self.node_name
        if self.operate_detail:
            if hasattr(self.operate_detail, 'to_alipay_dict'):
                params['operate_detail'] = self.operate_detail.to_alipay_dict()
            else:
                params['operate_detail'] = self.operate_detail
        if self.operate_duration:
            if hasattr(self.operate_duration, 'to_alipay_dict'):
                params['operate_duration'] = self.operate_duration.to_alipay_dict()
            else:
                params['operate_duration'] = self.operate_duration
        if self.operate_time:
            if hasattr(self.operate_time, 'to_alipay_dict'):
                params['operate_time'] = self.operate_time.to_alipay_dict()
            else:
                params['operate_time'] = self.operate_time
        if self.operate_type:
            if hasattr(self.operate_type, 'to_alipay_dict'):
                params['operate_type'] = self.operate_type.to_alipay_dict()
            else:
                params['operate_type'] = self.operate_type
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.operator_name:
            if hasattr(self.operator_name, 'to_alipay_dict'):
                params['operator_name'] = self.operator_name.to_alipay_dict()
            else:
                params['operator_name'] = self.operator_name
        if self.operator_work_no:
            if hasattr(self.operator_work_no, 'to_alipay_dict'):
                params['operator_work_no'] = self.operator_work_no.to_alipay_dict()
            else:
                params['operator_work_no'] = self.operator_work_no
        if self.ticket_state:
            if hasattr(self.ticket_state, 'to_alipay_dict'):
                params['ticket_state'] = self.ticket_state.to_alipay_dict()
            else:
                params['ticket_state'] = self.ticket_state
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NodeOperateDTO()
        if 'ant_process_puid' in d:
            o.ant_process_puid = d['ant_process_puid']
        if 'biz_app' in d:
            o.biz_app = d['biz_app']
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'memo' in d:
            o.memo = d['memo']
        if 'node_display_name' in d:
            o.node_display_name = d['node_display_name']
        if 'node_duration' in d:
            o.node_duration = d['node_duration']
        if 'node_name' in d:
            o.node_name = d['node_name']
        if 'operate_detail' in d:
            o.operate_detail = d['operate_detail']
        if 'operate_duration' in d:
            o.operate_duration = d['operate_duration']
        if 'operate_time' in d:
            o.operate_time = d['operate_time']
        if 'operate_type' in d:
            o.operate_type = d['operate_type']
        if 'operator' in d:
            o.operator = d['operator']
        if 'operator_name' in d:
            o.operator_name = d['operator_name']
        if 'operator_work_no' in d:
            o.operator_work_no = d['operator_work_no']
        if 'ticket_state' in d:
            o.ticket_state = d['ticket_state']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MultiCurrencyMoneyOpenApi(object):

    def __init__(self):
        self._cent = None
        self._currency_value = None

    @property
    def cent(self):
        return self._cent

    @cent.setter
    def cent(self, value):
        self._cent = value
    @property
    def currency_value(self):
        return self._currency_value

    @currency_value.setter
    def currency_value(self, value):
        self._currency_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.cent:
            if hasattr(self.cent, 'to_alipay_dict'):
                params['cent'] = self.cent.to_alipay_dict()
            else:
                params['cent'] = self.cent
        if self.currency_value:
            if hasattr(self.currency_value, 'to_alipay_dict'):
                params['currency_value'] = self.currency_value.to_alipay_dict()
            else:
                params['currency_value'] = self.currency_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MultiCurrencyMoneyOpenApi()
        if 'cent' in d:
            o.cent = d['cent']
        if 'currency_value' in d:
            o.currency_value = d['currency_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechAiCvUaAsyncQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechAiCvUaAsyncQueryResponse, self).__init__()
        self._host = None
        self._result_code = None
        self._result_detail = None
        self._result_msg = None
        self._result_success = None
        self._result_url = None
        self._status = None

    @property
    def host(self):
        return self._host

    @host.setter
    def host(self, value):
        self._host = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_detail(self):
        return self._result_detail

    @result_detail.setter
    def result_detail(self, value):
        self._result_detail = value
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value
    @property
    def result_success(self):
        return self._result_success

    @result_success.setter
    def result_success(self, value):
        self._result_success = value
    @property
    def result_url(self):
        return self._result_url

    @result_url.setter
    def result_url(self, value):
        self._result_url = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AnttechAiCvUaAsyncQueryResponse, self).parse_response_content(response_content)
        if 'host' in response:
            self.host = response['host']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_detail' in response:
            self.result_detail = response['result_detail']
        if 'result_msg' in response:
            self.result_msg = response['result_msg']
        if 'result_success' in response:
            self.result_success = response['result_success']
        if 'result_url' in response:
            self.result_url = response['result_url']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotMdeviceprodShopCreateModel(object):

    def __init__(self):
        self._address = None
        self._city = None
        self._creator_pid = None
        self._district = None
        self._ext_info = None
        self._industry_category = None
        self._merchant_pid = None
        self._province = None
        self._shop_name = None
        self._shop_property = None
        self._shop_type = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def creator_pid(self):
        return self._creator_pid

    @creator_pid.setter
    def creator_pid(self, value):
        self._creator_pid = value
    @property
    def district(self):
        return self._district

    @district.setter
    def district(self, value):
        self._district = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def industry_category(self):
        return self._industry_category

    @industry_category.setter
    def industry_category(self, value):
        self._industry_category = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_property(self):
        return self._shop_property

    @shop_property.setter
    def shop_property(self, value):
        self._shop_property = value
    @property
    def shop_type(self):
        return self._shop_type

    @shop_type.setter
    def shop_type(self, value):
        self._shop_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.creator_pid:
            if hasattr(self.creator_pid, 'to_alipay_dict'):
                params['creator_pid'] = self.creator_pid.to_alipay_dict()
            else:
                params['creator_pid'] = self.creator_pid
        if self.district:
            if hasattr(self.district, 'to_alipay_dict'):
                params['district'] = self.district.to_alipay_dict()
            else:
                params['district'] = self.district
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.industry_category:
            if hasattr(self.industry_category, 'to_alipay_dict'):
                params['industry_category'] = self.industry_category.to_alipay_dict()
            else:
                params['industry_category'] = self.industry_category
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.province:
            if hasattr(self.province, 'to_alipay_dict'):
                params['province'] = self.province.to_alipay_dict()
            else:
                params['province'] = self.province
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.shop_property:
            if hasattr(self.shop_property, 'to_alipay_dict'):
                params['shop_property'] = self.shop_property.to_alipay_dict()
            else:
                params['shop_property'] = self.shop_property
        if self.shop_type:
            if hasattr(self.shop_type, 'to_alipay_dict'):
                params['shop_type'] = self.shop_type.to_alipay_dict()
            else:
                params['shop_type'] = self.shop_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotMdeviceprodShopCreateModel()
        if 'address' in d:
            o.address = d['address']
        if 'city' in d:
            o.city = d['city']
        if 'creator_pid' in d:
            o.creator_pid = d['creator_pid']
        if 'district' in d:
            o.district = d['district']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'industry_category' in d:
            o.industry_category = d['industry_category']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'province' in d:
            o.province = d['province']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'shop_property' in d:
            o.shop_property = d['shop_property']
        if 'shop_type' in d:
            o.shop_type = d['shop_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.YunTaskShopStatisticInfo import YunTaskShopStatisticInfo


class AlipayCommerceYuntaskShopstatisticsQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceYuntaskShopstatisticsQueryResponse, self).__init__()
        self._page = None
        self._page_size = None
        self._task_shop_statistic_info = None
        self._total_size = None

    @property
    def page(self):
        return self._page

    @page.setter
    def page(self, value):
        self._page = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def task_shop_statistic_info(self):
        return self._task_shop_statistic_info

    @task_shop_statistic_info.setter
    def task_shop_statistic_info(self, value):
        if isinstance(value, list):
            self._task_shop_statistic_info = list()
            for i in value:
                if isinstance(i, YunTaskShopStatisticInfo):
                    self._task_shop_statistic_info.append(i)
                else:
                    self._task_shop_statistic_info.append(YunTaskShopStatisticInfo.from_alipay_dict(i))
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceYuntaskShopstatisticsQueryResponse, self).parse_response_content(response_content)
        if 'page' in response:
            self.page = response['page']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'task_shop_statistic_info' in response:
            self.task_shop_statistic_info = response['task_shop_statistic_info']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialGiftVoucherUseModel(object):

    def __init__(self):
        self._end_date = None
        self._mid = None
        self._order_id = None
        self._price = None
        self._start_date = None
        self._use_price = None
        self._voucher_id = None

    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def mid(self):
        return self._mid

    @mid.setter
    def mid(self, value):
        self._mid = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def use_price(self):
        return self._use_price

    @use_price.setter
    def use_price(self, value):
        self._use_price = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.mid:
            if hasattr(self.mid, 'to_alipay_dict'):
                params['mid'] = self.mid.to_alipay_dict()
            else:
                params['mid'] = self.mid
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.use_price:
            if hasattr(self.use_price, 'to_alipay_dict'):
                params['use_price'] = self.use_price.to_alipay_dict()
            else:
                params['use_price'] = self.use_price
        if self.voucher_id:
            if hasattr(self.voucher_id, 'to_alipay_dict'):
                params['voucher_id'] = self.voucher_id.to_alipay_dict()
            else:
                params['voucher_id'] = self.voucher_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialGiftVoucherUseModel()
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'mid' in d:
            o.mid = d['mid']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'price' in d:
            o.price = d['price']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'use_price' in d:
            o.use_price = d['use_price']
        if 'voucher_id' in d:
            o.voucher_id = d['voucher_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CommunityPartnerRelationDataSyncDTO import CommunityPartnerRelationDataSyncDTO


class AlipayOpenAppCommunityPartnerSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppCommunityPartnerSyncResponse, self).__init__()
        self._target_list = None

    @property
    def target_list(self):
        return self._target_list

    @target_list.setter
    def target_list(self, value):
        if isinstance(value, list):
            self._target_list = list()
            for i in value:
                if isinstance(i, CommunityPartnerRelationDataSyncDTO):
                    self._target_list.append(i)
                else:
                    self._target_list.append(CommunityPartnerRelationDataSyncDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppCommunityPartnerSyncResponse, self).parse_response_content(response_content)
        if 'target_list' in response:
            self.target_list = response['target_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DatadigitalFincloudFinsaasOperationtaskQueryModel(object):

    def __init__(self):
        self._operation_task_id = None
        self._tenant_code = None

    @property
    def operation_task_id(self):
        return self._operation_task_id

    @operation_task_id.setter
    def operation_task_id(self, value):
        self._operation_task_id = value
    @property
    def tenant_code(self):
        return self._tenant_code

    @tenant_code.setter
    def tenant_code(self, value):
        self._tenant_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.operation_task_id:
            if hasattr(self.operation_task_id, 'to_alipay_dict'):
                params['operation_task_id'] = self.operation_task_id.to_alipay_dict()
            else:
                params['operation_task_id'] = self.operation_task_id
        if self.tenant_code:
            if hasattr(self.tenant_code, 'to_alipay_dict'):
                params['tenant_code'] = self.tenant_code.to_alipay_dict()
            else:
                params['tenant_code'] = self.tenant_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DatadigitalFincloudFinsaasOperationtaskQueryModel()
        if 'operation_task_id' in d:
            o.operation_task_id = d['operation_task_id']
        if 'tenant_code' in d:
            o.tenant_code = d['tenant_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SsdataDataserviceDtevalDataanalysisSendModel(object):

    def __init__(self):
        self._biz_number = None
        self._biz_source = None
        self._data_content = None
        self._process_biz_type = None

    @property
    def biz_number(self):
        return self._biz_number

    @biz_number.setter
    def biz_number(self, value):
        self._biz_number = value
    @property
    def biz_source(self):
        return self._biz_source

    @biz_source.setter
    def biz_source(self, value):
        self._biz_source = value
    @property
    def data_content(self):
        return self._data_content

    @data_content.setter
    def data_content(self, value):
        self._data_content = value
    @property
    def process_biz_type(self):
        return self._process_biz_type

    @process_biz_type.setter
    def process_biz_type(self, value):
        self._process_biz_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_number:
            if hasattr(self.biz_number, 'to_alipay_dict'):
                params['biz_number'] = self.biz_number.to_alipay_dict()
            else:
                params['biz_number'] = self.biz_number
        if self.biz_source:
            if hasattr(self.biz_source, 'to_alipay_dict'):
                params['biz_source'] = self.biz_source.to_alipay_dict()
            else:
                params['biz_source'] = self.biz_source
        if self.data_content:
            if hasattr(self.data_content, 'to_alipay_dict'):
                params['data_content'] = self.data_content.to_alipay_dict()
            else:
                params['data_content'] = self.data_content
        if self.process_biz_type:
            if hasattr(self.process_biz_type, 'to_alipay_dict'):
                params['process_biz_type'] = self.process_biz_type.to_alipay_dict()
            else:
                params['process_biz_type'] = self.process_biz_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SsdataDataserviceDtevalDataanalysisSendModel()
        if 'biz_number' in d:
            o.biz_number = d['biz_number']
        if 'biz_source' in d:
            o.biz_source = d['biz_source']
        if 'data_content' in d:
            o.data_content = d['data_content']
        if 'process_biz_type' in d:
            o.process_biz_type = d['process_biz_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoActivityRecycleSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoActivityRecycleSendResponse, self).__init__()
        self._full_energy = None

    @property
    def full_energy(self):
        return self._full_energy

    @full_energy.setter
    def full_energy(self, value):
        self._full_energy = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoActivityRecycleSendResponse, self).parse_response_content(response_content)
        if 'full_energy' in response:
            self.full_energy = response['full_energy']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingMiniapptestQueryModel(object):

    def __init__(self):
        self._xxxx = None

    @property
    def xxxx(self):
        return self._xxxx

    @xxxx.setter
    def xxxx(self, value):
        self._xxxx = value


    def to_alipay_dict(self):
        params = dict()
        if self.xxxx:
            if hasattr(self.xxxx, 'to_alipay_dict'):
                params['xxxx'] = self.xxxx.to_alipay_dict()
            else:
                params['xxxx'] = self.xxxx
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingMiniapptestQueryModel()
        if 'xxxx' in d:
            o.xxxx = d['xxxx']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniInnerversionTemplatebasedUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniInnerversionTemplatebasedUploadResponse, self).__init__()


    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniInnerversionTemplatebasedUploadResponse, self).parse_response_content(response_content)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossProdAntlegalchainOrderModifyModel(object):

    def __init__(self):
        self._bas_data_id = None
        self._biz_unique_id = None
        self._corp_code = None
        self._corp_name = None
        self._email = None
        self._op_reason = None
        self._op_type = None
        self._request_app_name = None
        self._request_time_stamp = None
        self._request_token = None
        self._user_id = None

    @property
    def bas_data_id(self):
        return self._bas_data_id

    @bas_data_id.setter
    def bas_data_id(self, value):
        self._bas_data_id = value
    @property
    def biz_unique_id(self):
        return self._biz_unique_id

    @biz_unique_id.setter
    def biz_unique_id(self, value):
        self._biz_unique_id = value
    @property
    def corp_code(self):
        return self._corp_code

    @corp_code.setter
    def corp_code(self, value):
        self._corp_code = value
    @property
    def corp_name(self):
        return self._corp_name

    @corp_name.setter
    def corp_name(self, value):
        self._corp_name = value
    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def op_reason(self):
        return self._op_reason

    @op_reason.setter
    def op_reason(self, value):
        self._op_reason = value
    @property
    def op_type(self):
        return self._op_type

    @op_type.setter
    def op_type(self, value):
        self._op_type = value
    @property
    def request_app_name(self):
        return self._request_app_name

    @request_app_name.setter
    def request_app_name(self, value):
        self._request_app_name = value
    @property
    def request_time_stamp(self):
        return self._request_time_stamp

    @request_time_stamp.setter
    def request_time_stamp(self, value):
        self._request_time_stamp = value
    @property
    def request_token(self):
        return self._request_token

    @request_token.setter
    def request_token(self, value):
        self._request_token = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.bas_data_id:
            if hasattr(self.bas_data_id, 'to_alipay_dict'):
                params['bas_data_id'] = self.bas_data_id.to_alipay_dict()
            else:
                params['bas_data_id'] = self.bas_data_id
        if self.biz_unique_id:
            if hasattr(self.biz_unique_id, 'to_alipay_dict'):
                params['biz_unique_id'] = self.biz_unique_id.to_alipay_dict()
            else:
                params['biz_unique_id'] = self.biz_unique_id
        if self.corp_code:
            if hasattr(self.corp_code, 'to_alipay_dict'):
                params['corp_code'] = self.corp_code.to_alipay_dict()
            else:
                params['corp_code'] = self.corp_code
        if self.corp_name:
            if hasattr(self.corp_name, 'to_alipay_dict'):
                params['corp_name'] = self.corp_name.to_alipay_dict()
            else:
                params['corp_name'] = self.corp_name
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.op_reason:
            if hasattr(self.op_reason, 'to_alipay_dict'):
                params['op_reason'] = self.op_reason.to_alipay_dict()
            else:
                params['op_reason'] = self.op_reason
        if self.op_type:
            if hasattr(self.op_type, 'to_alipay_dict'):
                params['op_type'] = self.op_type.to_alipay_dict()
            else:
                params['op_type'] = self.op_type
        if self.request_app_name:
            if hasattr(self.request_app_name, 'to_alipay_dict'):
                params['request_app_name'] = self.request_app_name.to_alipay_dict()
            else:
                params['request_app_name'] = self.request_app_name
        if self.request_time_stamp:
            if hasattr(self.request_time_stamp, 'to_alipay_dict'):
                params['request_time_stamp'] = self.request_time_stamp.to_alipay_dict()
            else:
                params['request_time_stamp'] = self.request_time_stamp
        if self.request_token:
            if hasattr(self.request_token, 'to_alipay_dict'):
                params['request_token'] = self.request_token.to_alipay_dict()
            else:
                params['request_token'] = self.request_token
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossProdAntlegalchainOrderModifyModel()
        if 'bas_data_id' in d:
            o.bas_data_id = d['bas_data_id']
        if 'biz_unique_id' in d:
            o.biz_unique_id = d['biz_unique_id']
        if 'corp_code' in d:
            o.corp_code = d['corp_code']
        if 'corp_name' in d:
            o.corp_name = d['corp_name']
        if 'email' in d:
            o.email = d['email']
        if 'op_reason' in d:
            o.op_reason = d['op_reason']
        if 'op_type' in d:
            o.op_type = d['op_type']
        if 'request_app_name' in d:
            o.request_app_name = d['request_app_name']
        if 'request_time_stamp' in d:
            o.request_time_stamp = d['request_time_stamp']
        if 'request_token' in d:
            o.request_token = d['request_token']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PosDishGroupModel import PosDishGroupModel


class KoubeiCateringPosDishgroupSyncModel(object):

    def __init__(self):
        self._pos_dish_group_model = None

    @property
    def pos_dish_group_model(self):
        return self._pos_dish_group_model

    @pos_dish_group_model.setter
    def pos_dish_group_model(self, value):
        if isinstance(value, PosDishGroupModel):
            self._pos_dish_group_model = value
        else:
            self._pos_dish_group_model = PosDishGroupModel.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.pos_dish_group_model:
            if hasattr(self.pos_dish_group_model, 'to_alipay_dict'):
                params['pos_dish_group_model'] = self.pos_dish_group_model.to_alipay_dict()
            else:
                params['pos_dish_group_model'] = self.pos_dish_group_model
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringPosDishgroupSyncModel()
        if 'pos_dish_group_model' in d:
            o.pos_dish_group_model = d['pos_dish_group_model']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CPCommServices import CPCommServices


class AlipayEcoCplifeCommunityDetailsQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoCplifeCommunityDetailsQueryResponse, self).__init__()
        self._associated_pois = None
        self._audit_status = None
        self._city_code = None
        self._community_address = None
        self._community_locations = None
        self._community_name = None
        self._community_services = None
        self._community_status = None
        self._district_code = None
        self._gmt_created = None
        self._gmt_modified = None
        self._hotline = None
        self._isv_pid = None
        self._merchant_firm_name = None
        self._merchant_pid = None
        self._next_action = None
        self._out_community_id = None
        self._province_code = None
        self._qr_code_image = None

    @property
    def associated_pois(self):
        return self._associated_pois

    @associated_pois.setter
    def associated_pois(self, value):
        if isinstance(value, list):
            self._associated_pois = list()
            for i in value:
                self._associated_pois.append(i)
    @property
    def audit_status(self):
        return self._audit_status

    @audit_status.setter
    def audit_status(self, value):
        self._audit_status = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def community_address(self):
        return self._community_address

    @community_address.setter
    def community_address(self, value):
        self._community_address = value
    @property
    def community_locations(self):
        return self._community_locations

    @community_locations.setter
    def community_locations(self, value):
        if isinstance(value, list):
            self._community_locations = list()
            for i in value:
                self._community_locations.append(i)
    @property
    def community_name(self):
        return self._community_name

    @community_name.setter
    def community_name(self, value):
        self._community_name = value
    @property
    def community_services(self):
        return self._community_services

    @community_services.setter
    def community_services(self, value):
        if isinstance(value, list):
            self._community_services = list()
            for i in value:
                if isinstance(i, CPCommServices):
                    self._community_services.append(i)
                else:
                    self._community_services.append(CPCommServices.from_alipay_dict(i))
    @property
    def community_status(self):
        return self._community_status

    @community_status.setter
    def community_status(self, value):
        self._community_status = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def gmt_created(self):
        return self._gmt_created

    @gmt_created.setter
    def gmt_created(self, value):
        self._gmt_created = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def hotline(self):
        return self._hotline

    @hotline.setter
    def hotline(self, value):
        self._hotline = value
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def merchant_firm_name(self):
        return self._merchant_firm_name

    @merchant_firm_name.setter
    def merchant_firm_name(self, value):
        self._merchant_firm_name = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def next_action(self):
        return self._next_action

    @next_action.setter
    def next_action(self, value):
        self._next_action = value
    @property
    def out_community_id(self):
        return self._out_community_id

    @out_community_id.setter
    def out_community_id(self, value):
        self._out_community_id = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def qr_code_image(self):
        return self._qr_code_image

    @qr_code_image.setter
    def qr_code_image(self, value):
        self._qr_code_image = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoCplifeCommunityDetailsQueryResponse, self).parse_response_content(response_content)
        if 'associated_pois' in response:
            self.associated_pois = response['associated_pois']
        if 'audit_status' in response:
            self.audit_status = response['audit_status']
        if 'city_code' in response:
            self.city_code = response['city_code']
        if 'community_address' in response:
            self.community_address = response['community_address']
        if 'community_locations' in response:
            self.community_locations = response['community_locations']
        if 'community_name' in response:
            self.community_name = response['community_name']
        if 'community_services' in response:
            self.community_services = response['community_services']
        if 'community_status' in response:
            self.community_status = response['community_status']
        if 'district_code' in response:
            self.district_code = response['district_code']
        if 'gmt_created' in response:
            self.gmt_created = response['gmt_created']
        if 'gmt_modified' in response:
            self.gmt_modified = response['gmt_modified']
        if 'hotline' in response:
            self.hotline = response['hotline']
        if 'isv_pid' in response:
            self.isv_pid = response['isv_pid']
        if 'merchant_firm_name' in response:
            self.merchant_firm_name = response['merchant_firm_name']
        if 'merchant_pid' in response:
            self.merchant_pid = response['merchant_pid']
        if 'next_action' in response:
            self.next_action = response['next_action']
        if 'out_community_id' in response:
            self.out_community_id = response['out_community_id']
        if 'province_code' in response:
            self.province_code = response['province_code']
        if 'qr_code_image' in response:
            self.qr_code_image = response['qr_code_image']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditSceneprodLoanCancelModel(object):

    def __init__(self):
        self._cancel_reason = None
        self._mybk_order_no = None
        self._org_code = None
        self._out_order_no = None
        self._product_code = None
        self._site = None
        self._site_user_id = None

    @property
    def cancel_reason(self):
        return self._cancel_reason

    @cancel_reason.setter
    def cancel_reason(self, value):
        self._cancel_reason = value
    @property
    def mybk_order_no(self):
        return self._mybk_order_no

    @mybk_order_no.setter
    def mybk_order_no(self, value):
        self._mybk_order_no = value
    @property
    def org_code(self):
        return self._org_code

    @org_code.setter
    def org_code(self, value):
        self._org_code = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def site(self):
        return self._site

    @site.setter
    def site(self, value):
        self._site = value
    @property
    def site_user_id(self):
        return self._site_user_id

    @site_user_id.setter
    def site_user_id(self, value):
        self._site_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.cancel_reason:
            if hasattr(self.cancel_reason, 'to_alipay_dict'):
                params['cancel_reason'] = self.cancel_reason.to_alipay_dict()
            else:
                params['cancel_reason'] = self.cancel_reason
        if self.mybk_order_no:
            if hasattr(self.mybk_order_no, 'to_alipay_dict'):
                params['mybk_order_no'] = self.mybk_order_no.to_alipay_dict()
            else:
                params['mybk_order_no'] = self.mybk_order_no
        if self.org_code:
            if hasattr(self.org_code, 'to_alipay_dict'):
                params['org_code'] = self.org_code.to_alipay_dict()
            else:
                params['org_code'] = self.org_code
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.site:
            if hasattr(self.site, 'to_alipay_dict'):
                params['site'] = self.site.to_alipay_dict()
            else:
                params['site'] = self.site
        if self.site_user_id:
            if hasattr(self.site_user_id, 'to_alipay_dict'):
                params['site_user_id'] = self.site_user_id.to_alipay_dict()
            else:
                params['site_user_id'] = self.site_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditSceneprodLoanCancelModel()
        if 'cancel_reason' in d:
            o.cancel_reason = d['cancel_reason']
        if 'mybk_order_no' in d:
            o.mybk_order_no = d['mybk_order_no']
        if 'org_code' in d:
            o.org_code = d['org_code']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'site' in d:
            o.site = d['site']
        if 'site_user_id' in d:
            o.site_user_id = d['site_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZolozAuthenticationFaceInitializeResponse(AlipayResponse):

    def __init__(self):
        super(ZolozAuthenticationFaceInitializeResponse, self).__init__()
        self._result = None
        self._ret_code_sub = None
        self._ret_message_sub = None
        self._zim_id = None

    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value
    @property
    def ret_code_sub(self):
        return self._ret_code_sub

    @ret_code_sub.setter
    def ret_code_sub(self, value):
        self._ret_code_sub = value
    @property
    def ret_message_sub(self):
        return self._ret_message_sub

    @ret_message_sub.setter
    def ret_message_sub(self, value):
        self._ret_message_sub = value
    @property
    def zim_id(self):
        return self._zim_id

    @zim_id.setter
    def zim_id(self, value):
        self._zim_id = value

    def parse_response_content(self, response_content):
        response = super(ZolozAuthenticationFaceInitializeResponse, self).parse_response_content(response_content)
        if 'result' in response:
            self.result = response['result']
        if 'ret_code_sub' in response:
            self.ret_code_sub = response['ret_code_sub']
        if 'ret_message_sub' in response:
            self.ret_message_sub = response['ret_message_sub']
        if 'zim_id' in response:
            self.zim_id = response['zim_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundAccountbookCardCreateModel(object):

    def __init__(self):
        self._ext_info = None
        self._merchant_user_id = None
        self._merchant_user_type = None
        self._scene_code = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def merchant_user_id(self):
        return self._merchant_user_id

    @merchant_user_id.setter
    def merchant_user_id(self, value):
        self._merchant_user_id = value
    @property
    def merchant_user_type(self):
        return self._merchant_user_type

    @merchant_user_type.setter
    def merchant_user_type(self, value):
        self._merchant_user_type = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.merchant_user_id:
            if hasattr(self.merchant_user_id, 'to_alipay_dict'):
                params['merchant_user_id'] = self.merchant_user_id.to_alipay_dict()
            else:
                params['merchant_user_id'] = self.merchant_user_id
        if self.merchant_user_type:
            if hasattr(self.merchant_user_type, 'to_alipay_dict'):
                params['merchant_user_type'] = self.merchant_user_type.to_alipay_dict()
            else:
                params['merchant_user_type'] = self.merchant_user_type
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundAccountbookCardCreateModel()
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'merchant_user_id' in d:
            o.merchant_user_id = d['merchant_user_id']
        if 'merchant_user_type' in d:
            o.merchant_user_type = d['merchant_user_type']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ChannelPutPlanDTO(object):

    def __init__(self):
        self._activity_page = None
        self._bill_way = None
        self._channel_biz_id = None
        self._channel_biz_id_str = None
        self._channel_categorychannel_category = None
        self._channel_id = None
        self._creator_id = None
        self._creator_name = None
        self._crowd_ids = None
        self._customize_page = None
        self._exc_end_time = None
        self._exc_start_time = None
        self._exception_reason = None
        self._gmt_create = None
        self._gmt_modified = None
        self._gmt_plan_end = None
        self._gmt_plan_start = None
        self._id = None
        self._modifier_id = None
        self._modifier_name = None
        self._name = None
        self._page_type = None
        self._plan_content = None
        self._plan_source = None
        self._reject_reason = None
        self._repeat_times = None
        self._status = None
        self._tenant_code = None

    @property
    def activity_page(self):
        return self._activity_page

    @activity_page.setter
    def activity_page(self, value):
        self._activity_page = value
    @property
    def bill_way(self):
        return self._bill_way

    @bill_way.setter
    def bill_way(self, value):
        self._bill_way = value
    @property
    def channel_biz_id(self):
        return self._channel_biz_id

    @channel_biz_id.setter
    def channel_biz_id(self, value):
        self._channel_biz_id = value
    @property
    def channel_biz_id_str(self):
        return self._channel_biz_id_str

    @channel_biz_id_str.setter
    def channel_biz_id_str(self, value):
        self._channel_biz_id_str = value
    @property
    def channel_categorychannel_category(self):
        return self._channel_categorychannel_category

    @channel_categorychannel_category.setter
    def channel_categorychannel_category(self, value):
        self._channel_categorychannel_category = value
    @property
    def channel_id(self):
        return self._channel_id

    @channel_id.setter
    def channel_id(self, value):
        self._channel_id = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def creator_name(self):
        return self._creator_name

    @creator_name.setter
    def creator_name(self, value):
        self._creator_name = value
    @property
    def crowd_ids(self):
        return self._crowd_ids

    @crowd_ids.setter
    def crowd_ids(self, value):
        self._crowd_ids = value
    @property
    def customize_page(self):
        return self._customize_page

    @customize_page.setter
    def customize_page(self, value):
        self._customize_page = value
    @property
    def exc_end_time(self):
        return self._exc_end_time

    @exc_end_time.setter
    def exc_end_time(self, value):
        self._exc_end_time = value
    @property
    def exc_start_time(self):
        return self._exc_start_time

    @exc_start_time.setter
    def exc_start_time(self, value):
        self._exc_start_time = value
    @property
    def exception_reason(self):
        return self._exception_reason

    @exception_reason.setter
    def exception_reason(self, value):
        self._exception_reason = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def gmt_plan_end(self):
        return self._gmt_plan_end

    @gmt_plan_end.setter
    def gmt_plan_end(self, value):
        self._gmt_plan_end = value
    @property
    def gmt_plan_start(self):
        return self._gmt_plan_start

    @gmt_plan_start.setter
    def gmt_plan_start(self, value):
        self._gmt_plan_start = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def modifier_id(self):
        return self._modifier_id

    @modifier_id.setter
    def modifier_id(self, value):
        self._modifier_id = value
    @property
    def modifier_name(self):
        return self._modifier_name

    @modifier_name.setter
    def modifier_name(self, value):
        self._modifier_name = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def page_type(self):
        return self._page_type

    @page_type.setter
    def page_type(self, value):
        self._page_type = value
    @property
    def plan_content(self):
        return self._plan_content

    @plan_content.setter
    def plan_content(self, value):
        self._plan_content = value
    @property
    def plan_source(self):
        return self._plan_source

    @plan_source.setter
    def plan_source(self, value):
        self._plan_source = value
    @property
    def reject_reason(self):
        return self._reject_reason

    @reject_reason.setter
    def reject_reason(self, value):
        self._reject_reason = value
    @property
    def repeat_times(self):
        return self._repeat_times

    @repeat_times.setter
    def repeat_times(self, value):
        self._repeat_times = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tenant_code(self):
        return self._tenant_code

    @tenant_code.setter
    def tenant_code(self, value):
        self._tenant_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_page:
            if hasattr(self.activity_page, 'to_alipay_dict'):
                params['activity_page'] = self.activity_page.to_alipay_dict()
            else:
                params['activity_page'] = self.activity_page
        if self.bill_way:
            if hasattr(self.bill_way, 'to_alipay_dict'):
                params['bill_way'] = self.bill_way.to_alipay_dict()
            else:
                params['bill_way'] = self.bill_way
        if self.channel_biz_id:
            if hasattr(self.channel_biz_id, 'to_alipay_dict'):
                params['channel_biz_id'] = self.channel_biz_id.to_alipay_dict()
            else:
                params['channel_biz_id'] = self.channel_biz_id
        if self.channel_biz_id_str:
            if hasattr(self.channel_biz_id_str, 'to_alipay_dict'):
                params['channel_biz_id_str'] = self.channel_biz_id_str.to_alipay_dict()
            else:
                params['channel_biz_id_str'] = self.channel_biz_id_str
        if self.channel_categorychannel_category:
            if hasattr(self.channel_categorychannel_category, 'to_alipay_dict'):
                params['channel_categorychannel_category'] = self.channel_categorychannel_category.to_alipay_dict()
            else:
                params['channel_categorychannel_category'] = self.channel_categorychannel_category
        if self.channel_id:
            if hasattr(self.channel_id, 'to_alipay_dict'):
                params['channel_id'] = self.channel_id.to_alipay_dict()
            else:
                params['channel_id'] = self.channel_id
        if self.creator_id:
            if hasattr(self.creator_id, 'to_alipay_dict'):
                params['creator_id'] = self.creator_id.to_alipay_dict()
            else:
                params['creator_id'] = self.creator_id
        if self.creator_name:
            if hasattr(self.creator_name, 'to_alipay_dict'):
                params['creator_name'] = self.creator_name.to_alipay_dict()
            else:
                params['creator_name'] = self.creator_name
        if self.crowd_ids:
            if hasattr(self.crowd_ids, 'to_alipay_dict'):
                params['crowd_ids'] = self.crowd_ids.to_alipay_dict()
            else:
                params['crowd_ids'] = self.crowd_ids
        if self.customize_page:
            if hasattr(self.customize_page, 'to_alipay_dict'):
                params['customize_page'] = self.customize_page.to_alipay_dict()
            else:
                params['customize_page'] = self.customize_page
        if self.exc_end_time:
            if hasattr(self.exc_end_time, 'to_alipay_dict'):
                params['exc_end_time'] = self.exc_end_time.to_alipay_dict()
            else:
                params['exc_end_time'] = self.exc_end_time
        if self.exc_start_time:
            if hasattr(self.exc_start_time, 'to_alipay_dict'):
                params['exc_start_time'] = self.exc_start_time.to_alipay_dict()
            else:
                params['exc_start_time'] = self.exc_start_time
        if self.exception_reason:
            if hasattr(self.exception_reason, 'to_alipay_dict'):
                params['exception_reason'] = self.exception_reason.to_alipay_dict()
            else:
                params['exception_reason'] = self.exception_reason
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.gmt_plan_end:
            if hasattr(self.gmt_plan_end, 'to_alipay_dict'):
                params['gmt_plan_end'] = self.gmt_plan_end.to_alipay_dict()
            else:
                params['gmt_plan_end'] = self.gmt_plan_end
        if self.gmt_plan_start:
            if hasattr(self.gmt_plan_start, 'to_alipay_dict'):
                params['gmt_plan_start'] = self.gmt_plan_start.to_alipay_dict()
            else:
                params['gmt_plan_start'] = self.gmt_plan_start
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.modifier_id:
            if hasattr(self.modifier_id, 'to_alipay_dict'):
                params['modifier_id'] = self.modifier_id.to_alipay_dict()
            else:
                params['modifier_id'] = self.modifier_id
        if self.modifier_name:
            if hasattr(self.modifier_name, 'to_alipay_dict'):
                params['modifier_name'] = self.modifier_name.to_alipay_dict()
            else:
                params['modifier_name'] = self.modifier_name
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.page_type:
            if hasattr(self.page_type, 'to_alipay_dict'):
                params['page_type'] = self.page_type.to_alipay_dict()
            else:
                params['page_type'] = self.page_type
        if self.plan_content:
            if hasattr(self.plan_content, 'to_alipay_dict'):
                params['plan_content'] = self.plan_content.to_alipay_dict()
            else:
                params['plan_content'] = self.plan_content
        if self.plan_source:
            if hasattr(self.plan_source, 'to_alipay_dict'):
                params['plan_source'] = self.plan_source.to_alipay_dict()
            else:
                params['plan_source'] = self.plan_source
        if self.reject_reason:
            if hasattr(self.reject_reason, 'to_alipay_dict'):
                params['reject_reason'] = self.reject_reason.to_alipay_dict()
            else:
                params['reject_reason'] = self.reject_reason
        if self.repeat_times:
            if hasattr(self.repeat_times, 'to_alipay_dict'):
                params['repeat_times'] = self.repeat_times.to_alipay_dict()
            else:
                params['repeat_times'] = self.repeat_times
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tenant_code:
            if hasattr(self.tenant_code, 'to_alipay_dict'):
                params['tenant_code'] = self.tenant_code.to_alipay_dict()
            else:
                params['tenant_code'] = self.tenant_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ChannelPutPlanDTO()
        if 'activity_page' in d:
            o.activity_page = d['activity_page']
        if 'bill_way' in d:
            o.bill_way = d['bill_way']
        if 'channel_biz_id' in d:
            o.channel_biz_id = d['channel_biz_id']
        if 'channel_biz_id_str' in d:
            o.channel_biz_id_str = d['channel_biz_id_str']
        if 'channel_categorychannel_category' in d:
            o.channel_categorychannel_category = d['channel_categorychannel_category']
        if 'channel_id' in d:
            o.channel_id = d['channel_id']
        if 'creator_id' in d:
            o.creator_id = d['creator_id']
        if 'creator_name' in d:
            o.creator_name = d['creator_name']
        if 'crowd_ids' in d:
            o.crowd_ids = d['crowd_ids']
        if 'customize_page' in d:
            o.customize_page = d['customize_page']
        if 'exc_end_time' in d:
            o.exc_end_time = d['exc_end_time']
        if 'exc_start_time' in d:
            o.exc_start_time = d['exc_start_time']
        if 'exception_reason' in d:
            o.exception_reason = d['exception_reason']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'gmt_plan_end' in d:
            o.gmt_plan_end = d['gmt_plan_end']
        if 'gmt_plan_start' in d:
            o.gmt_plan_start = d['gmt_plan_start']
        if 'id' in d:
            o.id = d['id']
        if 'modifier_id' in d:
            o.modifier_id = d['modifier_id']
        if 'modifier_name' in d:
            o.modifier_name = d['modifier_name']
        if 'name' in d:
            o.name = d['name']
        if 'page_type' in d:
            o.page_type = d['page_type']
        if 'plan_content' in d:
            o.plan_content = d['plan_content']
        if 'plan_source' in d:
            o.plan_source = d['plan_source']
        if 'reject_reason' in d:
            o.reject_reason = d['reject_reason']
        if 'repeat_times' in d:
            o.repeat_times = d['repeat_times']
        if 'status' in d:
            o.status = d['status']
        if 'tenant_code' in d:
            o.tenant_code = d['tenant_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AppTestInfo import AppTestInfo


class AlipayOpenOperationIspTestUseResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenOperationIspTestUseResponse, self).__init__()
        self._app_info = None
        self._output = None

    @property
    def app_info(self):
        return self._app_info

    @app_info.setter
    def app_info(self, value):
        if isinstance(value, list):
            self._app_info = list()
            for i in value:
                if isinstance(i, AppTestInfo):
                    self._app_info.append(i)
                else:
                    self._app_info.append(AppTestInfo.from_alipay_dict(i))
    @property
    def output(self):
        return self._output

    @output.setter
    def output(self, value):
        self._output = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenOperationIspTestUseResponse, self).parse_response_content(response_content)
        if 'app_info' in response:
            self.app_info = response['app_info']
        if 'output' in response:
            self.output = response['output']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotNetflowInfoQueryModel(object):

    def __init__(self):
        self._device_tag = None

    @property
    def device_tag(self):
        return self._device_tag

    @device_tag.setter
    def device_tag(self, value):
        self._device_tag = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_tag:
            if hasattr(self.device_tag, 'to_alipay_dict'):
                params['device_tag'] = self.device_tag.to_alipay_dict()
            else:
                params['device_tag'] = self.device_tag
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotNetflowInfoQueryModel()
        if 'device_tag' in d:
            o.device_tag = d['device_tag']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class WidgetGoodsInfo(object):

    def __init__(self):
        self._buying_url = None
        self._goods_brand = None
        self._goods_comment = None
        self._goods_description_label = None
        self._goods_id = None
        self._goods_label = None
        self._goods_name = None
        self._goods_type = None
        self._main_pic_url = None
        self._need_public_promo = None
        self._order_number = None
        self._original_price = None
        self._publish_cities = None
        self._remaining_quantity = None
        self._sell_price = None
        self._sell_tag_list = None
        self._sold_quantity = None
        self._status = None
        self._total_quantity = None

    @property
    def buying_url(self):
        return self._buying_url

    @buying_url.setter
    def buying_url(self, value):
        self._buying_url = value
    @property
    def goods_brand(self):
        return self._goods_brand

    @goods_brand.setter
    def goods_brand(self, value):
        self._goods_brand = value
    @property
    def goods_comment(self):
        return self._goods_comment

    @goods_comment.setter
    def goods_comment(self, value):
        self._goods_comment = value
    @property
    def goods_description_label(self):
        return self._goods_description_label

    @goods_description_label.setter
    def goods_description_label(self, value):
        self._goods_description_label = value
    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def goods_label(self):
        return self._goods_label

    @goods_label.setter
    def goods_label(self, value):
        self._goods_label = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def goods_type(self):
        return self._goods_type

    @goods_type.setter
    def goods_type(self, value):
        self._goods_type = value
    @property
    def main_pic_url(self):
        return self._main_pic_url

    @main_pic_url.setter
    def main_pic_url(self, value):
        self._main_pic_url = value
    @property
    def need_public_promo(self):
        return self._need_public_promo

    @need_public_promo.setter
    def need_public_promo(self, value):
        self._need_public_promo = value
    @property
    def order_number(self):
        return self._order_number

    @order_number.setter
    def order_number(self, value):
        self._order_number = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def publish_cities(self):
        return self._publish_cities

    @publish_cities.setter
    def publish_cities(self, value):
        self._publish_cities = value
    @property
    def remaining_quantity(self):
        return self._remaining_quantity

    @remaining_quantity.setter
    def remaining_quantity(self, value):
        self._remaining_quantity = value
    @property
    def sell_price(self):
        return self._sell_price

    @sell_price.setter
    def sell_price(self, value):
        self._sell_price = value
    @property
    def sell_tag_list(self):
        return self._sell_tag_list

    @sell_tag_list.setter
    def sell_tag_list(self, value):
        if isinstance(value, list):
            self._sell_tag_list = list()
            for i in value:
                self._sell_tag_list.append(i)
    @property
    def sold_quantity(self):
        return self._sold_quantity

    @sold_quantity.setter
    def sold_quantity(self, value):
        self._sold_quantity = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def total_quantity(self):
        return self._total_quantity

    @total_quantity.setter
    def total_quantity(self, value):
        self._total_quantity = value


    def to_alipay_dict(self):
        params = dict()
        if self.buying_url:
            if hasattr(self.buying_url, 'to_alipay_dict'):
                params['buying_url'] = self.buying_url.to_alipay_dict()
            else:
                params['buying_url'] = self.buying_url
        if self.goods_brand:
            if hasattr(self.goods_brand, 'to_alipay_dict'):
                params['goods_brand'] = self.goods_brand.to_alipay_dict()
            else:
                params['goods_brand'] = self.goods_brand
        if self.goods_comment:
            if hasattr(self.goods_comment, 'to_alipay_dict'):
                params['goods_comment'] = self.goods_comment.to_alipay_dict()
            else:
                params['goods_comment'] = self.goods_comment
        if self.goods_description_label:
            if hasattr(self.goods_description_label, 'to_alipay_dict'):
                params['goods_description_label'] = self.goods_description_label.to_alipay_dict()
            else:
                params['goods_description_label'] = self.goods_description_label
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.goods_label:
            if hasattr(self.goods_label, 'to_alipay_dict'):
                params['goods_label'] = self.goods_label.to_alipay_dict()
            else:
                params['goods_label'] = self.goods_label
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.goods_type:
            if hasattr(self.goods_type, 'to_alipay_dict'):
                params['goods_type'] = self.goods_type.to_alipay_dict()
            else:
                params['goods_type'] = self.goods_type
        if self.main_pic_url:
            if hasattr(self.main_pic_url, 'to_alipay_dict'):
                params['main_pic_url'] = self.main_pic_url.to_alipay_dict()
            else:
                params['main_pic_url'] = self.main_pic_url
        if self.need_public_promo:
            if hasattr(self.need_public_promo, 'to_alipay_dict'):
                params['need_public_promo'] = self.need_public_promo.to_alipay_dict()
            else:
                params['need_public_promo'] = self.need_public_promo
        if self.order_number:
            if hasattr(self.order_number, 'to_alipay_dict'):
                params['order_number'] = self.order_number.to_alipay_dict()
            else:
                params['order_number'] = self.order_number
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.publish_cities:
            if hasattr(self.publish_cities, 'to_alipay_dict'):
                params['publish_cities'] = self.publish_cities.to_alipay_dict()
            else:
                params['publish_cities'] = self.publish_cities
        if self.remaining_quantity:
            if hasattr(self.remaining_quantity, 'to_alipay_dict'):
                params['remaining_quantity'] = self.remaining_quantity.to_alipay_dict()
            else:
                params['remaining_quantity'] = self.remaining_quantity
        if self.sell_price:
            if hasattr(self.sell_price, 'to_alipay_dict'):
                params['sell_price'] = self.sell_price.to_alipay_dict()
            else:
                params['sell_price'] = self.sell_price
        if self.sell_tag_list:
            if isinstance(self.sell_tag_list, list):
                for i in range(0, len(self.sell_tag_list)):
                    element = self.sell_tag_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sell_tag_list[i] = element.to_alipay_dict()
            if hasattr(self.sell_tag_list, 'to_alipay_dict'):
                params['sell_tag_list'] = self.sell_tag_list.to_alipay_dict()
            else:
                params['sell_tag_list'] = self.sell_tag_list
        if self.sold_quantity:
            if hasattr(self.sold_quantity, 'to_alipay_dict'):
                params['sold_quantity'] = self.sold_quantity.to_alipay_dict()
            else:
                params['sold_quantity'] = self.sold_quantity
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.total_quantity:
            if hasattr(self.total_quantity, 'to_alipay_dict'):
                params['total_quantity'] = self.total_quantity.to_alipay_dict()
            else:
                params['total_quantity'] = self.total_quantity
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = WidgetGoodsInfo()
        if 'buying_url' in d:
            o.buying_url = d['buying_url']
        if 'goods_brand' in d:
            o.goods_brand = d['goods_brand']
        if 'goods_comment' in d:
            o.goods_comment = d['goods_comment']
        if 'goods_description_label' in d:
            o.goods_description_label = d['goods_description_label']
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'goods_label' in d:
            o.goods_label = d['goods_label']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'goods_type' in d:
            o.goods_type = d['goods_type']
        if 'main_pic_url' in d:
            o.main_pic_url = d['main_pic_url']
        if 'need_public_promo' in d:
            o.need_public_promo = d['need_public_promo']
        if 'order_number' in d:
            o.order_number = d['order_number']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'publish_cities' in d:
            o.publish_cities = d['publish_cities']
        if 'remaining_quantity' in d:
            o.remaining_quantity = d['remaining_quantity']
        if 'sell_price' in d:
            o.sell_price = d['sell_price']
        if 'sell_tag_list' in d:
            o.sell_tag_list = d['sell_tag_list']
        if 'sold_quantity' in d:
            o.sold_quantity = d['sold_quantity']
        if 'status' in d:
            o.status = d['status']
        if 'total_quantity' in d:
            o.total_quantity = d['total_quantity']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CreativeDetail import CreativeDetail
from alipay.aop.api.domain.PageInfo import PageInfo


class PageCreative(object):

    def __init__(self):
        self._list = None
        self._pagination = None

    @property
    def list(self):
        return self._list

    @list.setter
    def list(self, value):
        if isinstance(value, list):
            self._list = list()
            for i in value:
                if isinstance(i, CreativeDetail):
                    self._list.append(i)
                else:
                    self._list.append(CreativeDetail.from_alipay_dict(i))
    @property
    def pagination(self):
        return self._pagination

    @pagination.setter
    def pagination(self, value):
        if isinstance(value, PageInfo):
            self._pagination = value
        else:
            self._pagination = PageInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.list:
            if isinstance(self.list, list):
                for i in range(0, len(self.list)):
                    element = self.list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.list[i] = element.to_alipay_dict()
            if hasattr(self.list, 'to_alipay_dict'):
                params['list'] = self.list.to_alipay_dict()
            else:
                params['list'] = self.list
        if self.pagination:
            if hasattr(self.pagination, 'to_alipay_dict'):
                params['pagination'] = self.pagination.to_alipay_dict()
            else:
                params['pagination'] = self.pagination
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PageCreative()
        if 'list' in d:
            o.list = d['list']
        if 'pagination' in d:
            o.pagination = d['pagination']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SearchBoxExclusiveMarketingInfoRequest import SearchBoxExclusiveMarketingInfoRequest


class BoxExclusiveMarketingPageQueryDTO(object):

    def __init__(self):
        self._page_data = None
        self._page_num = None
        self._page_size = None
        self._total_number = None

    @property
    def page_data(self):
        return self._page_data

    @page_data.setter
    def page_data(self, value):
        if isinstance(value, list):
            self._page_data = list()
            for i in value:
                if isinstance(i, SearchBoxExclusiveMarketingInfoRequest):
                    self._page_data.append(i)
                else:
                    self._page_data.append(SearchBoxExclusiveMarketingInfoRequest.from_alipay_dict(i))
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total_number(self):
        return self._total_number

    @total_number.setter
    def total_number(self, value):
        self._total_number = value


    def to_alipay_dict(self):
        params = dict()
        if self.page_data:
            if isinstance(self.page_data, list):
                for i in range(0, len(self.page_data)):
                    element = self.page_data[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.page_data[i] = element.to_alipay_dict()
            if hasattr(self.page_data, 'to_alipay_dict'):
                params['page_data'] = self.page_data.to_alipay_dict()
            else:
                params['page_data'] = self.page_data
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.total_number:
            if hasattr(self.total_number, 'to_alipay_dict'):
                params['total_number'] = self.total_number.to_alipay_dict()
            else:
                params['total_number'] = self.total_number
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BoxExclusiveMarketingPageQueryDTO()
        if 'page_data' in d:
            o.page_data = d['page_data']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'total_number' in d:
            o.total_number = d['total_number']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AgWeatherDisasterHistory(object):

    def __init__(self):
        self._create_date = None
        self._high_temperature_days = None
        self._high_temperature_level = None
        self._low_temperature_days = None
        self._low_temperature_level = None
        self._rainstorm_days = None
        self._rainstorm_level = None
        self._update_date = None

    @property
    def create_date(self):
        return self._create_date

    @create_date.setter
    def create_date(self, value):
        self._create_date = value
    @property
    def high_temperature_days(self):
        return self._high_temperature_days

    @high_temperature_days.setter
    def high_temperature_days(self, value):
        self._high_temperature_days = value
    @property
    def high_temperature_level(self):
        return self._high_temperature_level

    @high_temperature_level.setter
    def high_temperature_level(self, value):
        self._high_temperature_level = value
    @property
    def low_temperature_days(self):
        return self._low_temperature_days

    @low_temperature_days.setter
    def low_temperature_days(self, value):
        self._low_temperature_days = value
    @property
    def low_temperature_level(self):
        return self._low_temperature_level

    @low_temperature_level.setter
    def low_temperature_level(self, value):
        self._low_temperature_level = value
    @property
    def rainstorm_days(self):
        return self._rainstorm_days

    @rainstorm_days.setter
    def rainstorm_days(self, value):
        self._rainstorm_days = value
    @property
    def rainstorm_level(self):
        return self._rainstorm_level

    @rainstorm_level.setter
    def rainstorm_level(self, value):
        self._rainstorm_level = value
    @property
    def update_date(self):
        return self._update_date

    @update_date.setter
    def update_date(self, value):
        self._update_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.create_date:
            if hasattr(self.create_date, 'to_alipay_dict'):
                params['create_date'] = self.create_date.to_alipay_dict()
            else:
                params['create_date'] = self.create_date
        if self.high_temperature_days:
            if hasattr(self.high_temperature_days, 'to_alipay_dict'):
                params['high_temperature_days'] = self.high_temperature_days.to_alipay_dict()
            else:
                params['high_temperature_days'] = self.high_temperature_days
        if self.high_temperature_level:
            if hasattr(self.high_temperature_level, 'to_alipay_dict'):
                params['high_temperature_level'] = self.high_temperature_level.to_alipay_dict()
            else:
                params['high_temperature_level'] = self.high_temperature_level
        if self.low_temperature_days:
            if hasattr(self.low_temperature_days, 'to_alipay_dict'):
                params['low_temperature_days'] = self.low_temperature_days.to_alipay_dict()
            else:
                params['low_temperature_days'] = self.low_temperature_days
        if self.low_temperature_level:
            if hasattr(self.low_temperature_level, 'to_alipay_dict'):
                params['low_temperature_level'] = self.low_temperature_level.to_alipay_dict()
            else:
                params['low_temperature_level'] = self.low_temperature_level
        if self.rainstorm_days:
            if hasattr(self.rainstorm_days, 'to_alipay_dict'):
                params['rainstorm_days'] = self.rainstorm_days.to_alipay_dict()
            else:
                params['rainstorm_days'] = self.rainstorm_days
        if self.rainstorm_level:
            if hasattr(self.rainstorm_level, 'to_alipay_dict'):
                params['rainstorm_level'] = self.rainstorm_level.to_alipay_dict()
            else:
                params['rainstorm_level'] = self.rainstorm_level
        if self.update_date:
            if hasattr(self.update_date, 'to_alipay_dict'):
                params['update_date'] = self.update_date.to_alipay_dict()
            else:
                params['update_date'] = self.update_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AgWeatherDisasterHistory()
        if 'create_date' in d:
            o.create_date = d['create_date']
        if 'high_temperature_days' in d:
            o.high_temperature_days = d['high_temperature_days']
        if 'high_temperature_level' in d:
            o.high_temperature_level = d['high_temperature_level']
        if 'low_temperature_days' in d:
            o.low_temperature_days = d['low_temperature_days']
        if 'low_temperature_level' in d:
            o.low_temperature_level = d['low_temperature_level']
        if 'rainstorm_days' in d:
            o.rainstorm_days = d['rainstorm_days']
        if 'rainstorm_level' in d:
            o.rainstorm_level = d['rainstorm_level']
        if 'update_date' in d:
            o.update_date = d['update_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechOceanbaseTestplatformTaskQueryModel(object):

    def __init__(self):
        self._end_time = None
        self._palyer = None
        self._run_task_retry = None
        self._run_task_time_out_minutes = None
        self._start_time = None
        self._test_cases = None
        self._test_info = None
        self._test_suite = None

    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def palyer(self):
        return self._palyer

    @palyer.setter
    def palyer(self, value):
        self._palyer = value
    @property
    def run_task_retry(self):
        return self._run_task_retry

    @run_task_retry.setter
    def run_task_retry(self, value):
        self._run_task_retry = value
    @property
    def run_task_time_out_minutes(self):
        return self._run_task_time_out_minutes

    @run_task_time_out_minutes.setter
    def run_task_time_out_minutes(self, value):
        self._run_task_time_out_minutes = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def test_cases(self):
        return self._test_cases

    @test_cases.setter
    def test_cases(self, value):
        self._test_cases = value
    @property
    def test_info(self):
        return self._test_info

    @test_info.setter
    def test_info(self, value):
        self._test_info = value
    @property
    def test_suite(self):
        return self._test_suite

    @test_suite.setter
    def test_suite(self, value):
        self._test_suite = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.palyer:
            if hasattr(self.palyer, 'to_alipay_dict'):
                params['palyer'] = self.palyer.to_alipay_dict()
            else:
                params['palyer'] = self.palyer
        if self.run_task_retry:
            if hasattr(self.run_task_retry, 'to_alipay_dict'):
                params['run_task_retry'] = self.run_task_retry.to_alipay_dict()
            else:
                params['run_task_retry'] = self.run_task_retry
        if self.run_task_time_out_minutes:
            if hasattr(self.run_task_time_out_minutes, 'to_alipay_dict'):
                params['run_task_time_out_minutes'] = self.run_task_time_out_minutes.to_alipay_dict()
            else:
                params['run_task_time_out_minutes'] = self.run_task_time_out_minutes
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.test_cases:
            if hasattr(self.test_cases, 'to_alipay_dict'):
                params['test_cases'] = self.test_cases.to_alipay_dict()
            else:
                params['test_cases'] = self.test_cases
        if self.test_info:
            if hasattr(self.test_info, 'to_alipay_dict'):
                params['test_info'] = self.test_info.to_alipay_dict()
            else:
                params['test_info'] = self.test_info
        if self.test_suite:
            if hasattr(self.test_suite, 'to_alipay_dict'):
                params['test_suite'] = self.test_suite.to_alipay_dict()
            else:
                params['test_suite'] = self.test_suite
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechOceanbaseTestplatformTaskQueryModel()
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'palyer' in d:
            o.palyer = d['palyer']
        if 'run_task_retry' in d:
            o.run_task_retry = d['run_task_retry']
        if 'run_task_time_out_minutes' in d:
            o.run_task_time_out_minutes = d['run_task_time_out_minutes']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'test_cases' in d:
            o.test_cases = d['test_cases']
        if 'test_info' in d:
            o.test_info = d['test_info']
        if 'test_suite' in d:
            o.test_suite = d['test_suite']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SignInfo import SignInfo


class AlipayFinancialnetPromotionApplyCreateModel(object):

    def __init__(self):
        self._apply_open_id = None
        self._apply_template_info = None
        self._apply_user_id = None
        self._asset_inst_id = None
        self._asset_resource_id = None
        self._entry_app_id = None
        self._finance_inst_iprole_id = None
        self._fund_inst_id = None
        self._org_code = None
        self._out_biz_no = None
        self._product_code = None
        self._promote_open_id = None
        self._promote_user_id = None
        self._sign_info = None

    @property
    def apply_open_id(self):
        return self._apply_open_id

    @apply_open_id.setter
    def apply_open_id(self, value):
        self._apply_open_id = value
    @property
    def apply_template_info(self):
        return self._apply_template_info

    @apply_template_info.setter
    def apply_template_info(self, value):
        self._apply_template_info = value
    @property
    def apply_user_id(self):
        return self._apply_user_id

    @apply_user_id.setter
    def apply_user_id(self, value):
        self._apply_user_id = value
    @property
    def asset_inst_id(self):
        return self._asset_inst_id

    @asset_inst_id.setter
    def asset_inst_id(self, value):
        self._asset_inst_id = value
    @property
    def asset_resource_id(self):
        return self._asset_resource_id

    @asset_resource_id.setter
    def asset_resource_id(self, value):
        self._asset_resource_id = value
    @property
    def entry_app_id(self):
        return self._entry_app_id

    @entry_app_id.setter
    def entry_app_id(self, value):
        self._entry_app_id = value
    @property
    def finance_inst_iprole_id(self):
        return self._finance_inst_iprole_id

    @finance_inst_iprole_id.setter
    def finance_inst_iprole_id(self, value):
        self._finance_inst_iprole_id = value
    @property
    def fund_inst_id(self):
        return self._fund_inst_id

    @fund_inst_id.setter
    def fund_inst_id(self, value):
        self._fund_inst_id = value
    @property
    def org_code(self):
        return self._org_code

    @org_code.setter
    def org_code(self, value):
        self._org_code = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def promote_open_id(self):
        return self._promote_open_id

    @promote_open_id.setter
    def promote_open_id(self, value):
        self._promote_open_id = value
    @property
    def promote_user_id(self):
        return self._promote_user_id

    @promote_user_id.setter
    def promote_user_id(self, value):
        self._promote_user_id = value
    @property
    def sign_info(self):
        return self._sign_info

    @sign_info.setter
    def sign_info(self, value):
        if isinstance(value, SignInfo):
            self._sign_info = value
        else:
            self._sign_info = SignInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.apply_open_id:
            if hasattr(self.apply_open_id, 'to_alipay_dict'):
                params['apply_open_id'] = self.apply_open_id.to_alipay_dict()
            else:
                params['apply_open_id'] = self.apply_open_id
        if self.apply_template_info:
            if hasattr(self.apply_template_info, 'to_alipay_dict'):
                params['apply_template_info'] = self.apply_template_info.to_alipay_dict()
            else:
                params['apply_template_info'] = self.apply_template_info
        if self.apply_user_id:
            if hasattr(self.apply_user_id, 'to_alipay_dict'):
                params['apply_user_id'] = self.apply_user_id.to_alipay_dict()
            else:
                params['apply_user_id'] = self.apply_user_id
        if self.asset_inst_id:
            if hasattr(self.asset_inst_id, 'to_alipay_dict'):
                params['asset_inst_id'] = self.asset_inst_id.to_alipay_dict()
            else:
                params['asset_inst_id'] = self.asset_inst_id
        if self.asset_resource_id:
            if hasattr(self.asset_resource_id, 'to_alipay_dict'):
                params['asset_resource_id'] = self.asset_resource_id.to_alipay_dict()
            else:
                params['asset_resource_id'] = self.asset_resource_id
        if self.entry_app_id:
            if hasattr(self.entry_app_id, 'to_alipay_dict'):
                params['entry_app_id'] = self.entry_app_id.to_alipay_dict()
            else:
                params['entry_app_id'] = self.entry_app_id
        if self.finance_inst_iprole_id:
            if hasattr(self.finance_inst_iprole_id, 'to_alipay_dict'):
                params['finance_inst_iprole_id'] = self.finance_inst_iprole_id.to_alipay_dict()
            else:
                params['finance_inst_iprole_id'] = self.finance_inst_iprole_id
        if self.fund_inst_id:
            if hasattr(self.fund_inst_id, 'to_alipay_dict'):
                params['fund_inst_id'] = self.fund_inst_id.to_alipay_dict()
            else:
                params['fund_inst_id'] = self.fund_inst_id
        if self.org_code:
            if hasattr(self.org_code, 'to_alipay_dict'):
                params['org_code'] = self.org_code.to_alipay_dict()
            else:
                params['org_code'] = self.org_code
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.promote_open_id:
            if hasattr(self.promote_open_id, 'to_alipay_dict'):
                params['promote_open_id'] = self.promote_open_id.to_alipay_dict()
            else:
                params['promote_open_id'] = self.promote_open_id
        if self.promote_user_id:
            if hasattr(self.promote_user_id, 'to_alipay_dict'):
                params['promote_user_id'] = self.promote_user_id.to_alipay_dict()
            else:
                params['promote_user_id'] = self.promote_user_id
        if self.sign_info:
            if hasattr(self.sign_info, 'to_alipay_dict'):
                params['sign_info'] = self.sign_info.to_alipay_dict()
            else:
                params['sign_info'] = self.sign_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFinancialnetPromotionApplyCreateModel()
        if 'apply_open_id' in d:
            o.apply_open_id = d['apply_open_id']
        if 'apply_template_info' in d:
            o.apply_template_info = d['apply_template_info']
        if 'apply_user_id' in d:
            o.apply_user_id = d['apply_user_id']
        if 'asset_inst_id' in d:
            o.asset_inst_id = d['asset_inst_id']
        if 'asset_resource_id' in d:
            o.asset_resource_id = d['asset_resource_id']
        if 'entry_app_id' in d:
            o.entry_app_id = d['entry_app_id']
        if 'finance_inst_iprole_id' in d:
            o.finance_inst_iprole_id = d['finance_inst_iprole_id']
        if 'fund_inst_id' in d:
            o.fund_inst_id = d['fund_inst_id']
        if 'org_code' in d:
            o.org_code = d['org_code']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'promote_open_id' in d:
            o.promote_open_id = d['promote_open_id']
        if 'promote_user_id' in d:
            o.promote_user_id = d['promote_user_id']
        if 'sign_info' in d:
            o.sign_info = d['sign_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportParkingPaymentinfoSyncModel(object):

    def __init__(self):
        self._free_exit_minutes = None
        self._is_encrypt_plate_no = None
        self._open_id = None
        self._out_serial_no = None
        self._payment_time = None
        self._payment_type = None
        self._plate_color = None
        self._plate_no = None
        self._service_url = None

    @property
    def free_exit_minutes(self):
        return self._free_exit_minutes

    @free_exit_minutes.setter
    def free_exit_minutes(self, value):
        self._free_exit_minutes = value
    @property
    def is_encrypt_plate_no(self):
        return self._is_encrypt_plate_no

    @is_encrypt_plate_no.setter
    def is_encrypt_plate_no(self, value):
        self._is_encrypt_plate_no = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_serial_no(self):
        return self._out_serial_no

    @out_serial_no.setter
    def out_serial_no(self, value):
        self._out_serial_no = value
    @property
    def payment_time(self):
        return self._payment_time

    @payment_time.setter
    def payment_time(self, value):
        self._payment_time = value
    @property
    def payment_type(self):
        return self._payment_type

    @payment_type.setter
    def payment_type(self, value):
        self._payment_type = value
    @property
    def plate_color(self):
        return self._plate_color

    @plate_color.setter
    def plate_color(self, value):
        self._plate_color = value
    @property
    def plate_no(self):
        return self._plate_no

    @plate_no.setter
    def plate_no(self, value):
        self._plate_no = value
    @property
    def service_url(self):
        return self._service_url

    @service_url.setter
    def service_url(self, value):
        self._service_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.free_exit_minutes:
            if hasattr(self.free_exit_minutes, 'to_alipay_dict'):
                params['free_exit_minutes'] = self.free_exit_minutes.to_alipay_dict()
            else:
                params['free_exit_minutes'] = self.free_exit_minutes
        if self.is_encrypt_plate_no:
            if hasattr(self.is_encrypt_plate_no, 'to_alipay_dict'):
                params['is_encrypt_plate_no'] = self.is_encrypt_plate_no.to_alipay_dict()
            else:
                params['is_encrypt_plate_no'] = self.is_encrypt_plate_no
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_serial_no:
            if hasattr(self.out_serial_no, 'to_alipay_dict'):
                params['out_serial_no'] = self.out_serial_no.to_alipay_dict()
            else:
                params['out_serial_no'] = self.out_serial_no
        if self.payment_time:
            if hasattr(self.payment_time, 'to_alipay_dict'):
                params['payment_time'] = self.payment_time.to_alipay_dict()
            else:
                params['payment_time'] = self.payment_time
        if self.payment_type:
            if hasattr(self.payment_type, 'to_alipay_dict'):
                params['payment_type'] = self.payment_type.to_alipay_dict()
            else:
                params['payment_type'] = self.payment_type
        if self.plate_color:
            if hasattr(self.plate_color, 'to_alipay_dict'):
                params['plate_color'] = self.plate_color.to_alipay_dict()
            else:
                params['plate_color'] = self.plate_color
        if self.plate_no:
            if hasattr(self.plate_no, 'to_alipay_dict'):
                params['plate_no'] = self.plate_no.to_alipay_dict()
            else:
                params['plate_no'] = self.plate_no
        if self.service_url:
            if hasattr(self.service_url, 'to_alipay_dict'):
                params['service_url'] = self.service_url.to_alipay_dict()
            else:
                params['service_url'] = self.service_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportParkingPaymentinfoSyncModel()
        if 'free_exit_minutes' in d:
            o.free_exit_minutes = d['free_exit_minutes']
        if 'is_encrypt_plate_no' in d:
            o.is_encrypt_plate_no = d['is_encrypt_plate_no']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_serial_no' in d:
            o.out_serial_no = d['out_serial_no']
        if 'payment_time' in d:
            o.payment_time = d['payment_time']
        if 'payment_type' in d:
            o.payment_type = d['payment_type']
        if 'plate_color' in d:
            o.plate_color = d['plate_color']
        if 'plate_no' in d:
            o.plate_no = d['plate_no']
        if 'service_url' in d:
            o.service_url = d['service_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceTitleFuzzyQueryModel(object):

    def __init__(self):
        self._enterprise_name = None
        self._m_short_name = None
        self._sub_m_short_name = None

    @property
    def enterprise_name(self):
        return self._enterprise_name

    @enterprise_name.setter
    def enterprise_name(self, value):
        self._enterprise_name = value
    @property
    def m_short_name(self):
        return self._m_short_name

    @m_short_name.setter
    def m_short_name(self, value):
        self._m_short_name = value
    @property
    def sub_m_short_name(self):
        return self._sub_m_short_name

    @sub_m_short_name.setter
    def sub_m_short_name(self, value):
        self._sub_m_short_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.enterprise_name:
            if hasattr(self.enterprise_name, 'to_alipay_dict'):
                params['enterprise_name'] = self.enterprise_name.to_alipay_dict()
            else:
                params['enterprise_name'] = self.enterprise_name
        if self.m_short_name:
            if hasattr(self.m_short_name, 'to_alipay_dict'):
                params['m_short_name'] = self.m_short_name.to_alipay_dict()
            else:
                params['m_short_name'] = self.m_short_name
        if self.sub_m_short_name:
            if hasattr(self.sub_m_short_name, 'to_alipay_dict'):
                params['sub_m_short_name'] = self.sub_m_short_name.to_alipay_dict()
            else:
                params['sub_m_short_name'] = self.sub_m_short_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceTitleFuzzyQueryModel()
        if 'enterprise_name' in d:
            o.enterprise_name = d['enterprise_name']
        if 'm_short_name' in d:
            o.m_short_name = d['m_short_name']
        if 'sub_m_short_name' in d:
            o.sub_m_short_name = d['sub_m_short_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserSessionGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserSessionGetResponse, self).__init__()
        self._open_id = None
        self._union_id = None

    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def union_id(self):
        return self._union_id

    @union_id.setter
    def union_id(self, value):
        self._union_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserSessionGetResponse, self).parse_response_content(response_content)
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'union_id' in response:
            self.union_id = response['union_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceKidsTokenCreateModel(object):

    def __init__(self):
        self._biz_data = None
        self._out_biz_no = None
        self._product_code = None
        self._scene_code = None

    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceKidsTokenCreateModel()
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditLoantradeRepayBudgetQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditLoantradeRepayBudgetQueryResponse, self).__init__()
        self._apply_repay_prin = None
        self._loan_ar_no = None
        self._should_repay_fee = None
        self._should_repay_int = None
        self._should_repay_penalty = None
        self._should_repay_pre_fee = None
        self._should_repay_prin = None

    @property
    def apply_repay_prin(self):
        return self._apply_repay_prin

    @apply_repay_prin.setter
    def apply_repay_prin(self, value):
        self._apply_repay_prin = value
    @property
    def loan_ar_no(self):
        return self._loan_ar_no

    @loan_ar_no.setter
    def loan_ar_no(self, value):
        self._loan_ar_no = value
    @property
    def should_repay_fee(self):
        return self._should_repay_fee

    @should_repay_fee.setter
    def should_repay_fee(self, value):
        self._should_repay_fee = value
    @property
    def should_repay_int(self):
        return self._should_repay_int

    @should_repay_int.setter
    def should_repay_int(self, value):
        self._should_repay_int = value
    @property
    def should_repay_penalty(self):
        return self._should_repay_penalty

    @should_repay_penalty.setter
    def should_repay_penalty(self, value):
        self._should_repay_penalty = value
    @property
    def should_repay_pre_fee(self):
        return self._should_repay_pre_fee

    @should_repay_pre_fee.setter
    def should_repay_pre_fee(self, value):
        self._should_repay_pre_fee = value
    @property
    def should_repay_prin(self):
        return self._should_repay_prin

    @should_repay_prin.setter
    def should_repay_prin(self, value):
        self._should_repay_prin = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditLoantradeRepayBudgetQueryResponse, self).parse_response_content(response_content)
        if 'apply_repay_prin' in response:
            self.apply_repay_prin = response['apply_repay_prin']
        if 'loan_ar_no' in response:
            self.loan_ar_no = response['loan_ar_no']
        if 'should_repay_fee' in response:
            self.should_repay_fee = response['should_repay_fee']
        if 'should_repay_int' in response:
            self.should_repay_int = response['should_repay_int']
        if 'should_repay_penalty' in response:
            self.should_repay_penalty = response['should_repay_penalty']
        if 'should_repay_pre_fee' in response:
            self.should_repay_pre_fee = response['should_repay_pre_fee']
        if 'should_repay_prin' in response:
            self.should_repay_prin = response['should_repay_prin']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IotDeliveryAgencyMerchantInfo import IotDeliveryAgencyMerchantInfo


class AlipayMarketingActivityIotdeliveryQueryModel(object):

    def __init__(self):
        self._belong_merchant_info = None
        self._delivery_id = None
        self._out_biz_no = None

    @property
    def belong_merchant_info(self):
        return self._belong_merchant_info

    @belong_merchant_info.setter
    def belong_merchant_info(self, value):
        if isinstance(value, IotDeliveryAgencyMerchantInfo):
            self._belong_merchant_info = value
        else:
            self._belong_merchant_info = IotDeliveryAgencyMerchantInfo.from_alipay_dict(value)
    @property
    def delivery_id(self):
        return self._delivery_id

    @delivery_id.setter
    def delivery_id(self, value):
        self._delivery_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.belong_merchant_info:
            if hasattr(self.belong_merchant_info, 'to_alipay_dict'):
                params['belong_merchant_info'] = self.belong_merchant_info.to_alipay_dict()
            else:
                params['belong_merchant_info'] = self.belong_merchant_info
        if self.delivery_id:
            if hasattr(self.delivery_id, 'to_alipay_dict'):
                params['delivery_id'] = self.delivery_id.to_alipay_dict()
            else:
                params['delivery_id'] = self.delivery_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivityIotdeliveryQueryModel()
        if 'belong_merchant_info' in d:
            o.belong_merchant_info = d['belong_merchant_info']
        if 'delivery_id' in d:
            o.delivery_id = d['delivery_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OrgRoleQuery import OrgRoleQuery
from alipay.aop.api.domain.QueryInfo import QueryInfo


class AlipayBossBaseAntauthorizeOrgroleQueryModel(object):

    def __init__(self):
        self._query = None
        self._query_info = None

    @property
    def query(self):
        return self._query

    @query.setter
    def query(self, value):
        if isinstance(value, OrgRoleQuery):
            self._query = value
        else:
            self._query = OrgRoleQuery.from_alipay_dict(value)
    @property
    def query_info(self):
        return self._query_info

    @query_info.setter
    def query_info(self, value):
        if isinstance(value, QueryInfo):
            self._query_info = value
        else:
            self._query_info = QueryInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.query:
            if hasattr(self.query, 'to_alipay_dict'):
                params['query'] = self.query.to_alipay_dict()
            else:
                params['query'] = self.query
        if self.query_info:
            if hasattr(self.query_info, 'to_alipay_dict'):
                params['query_info'] = self.query_info.to_alipay_dict()
            else:
                params['query_info'] = self.query_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossBaseAntauthorizeOrgroleQueryModel()
        if 'query' in d:
            o.query = d['query']
        if 'query_info' in d:
            o.query_info = d['query_info']
        return o


